@@ -3,6 +3,22 @@ import requests
 import numpy as np
 import json
 
+def clean_dict(obj, func):
+    if isinstance(obj, dict):
+        for key in list(obj.keys()):
+            if func(key):
+                del obj[key]
+            else:
+                clean_dict(obj[key], func)
+    elif isinstance(obj, list):
+        for i in reversed(range(len(obj))):
+            if func(obj[i]):
+                del obj[i]
+            else:
+                clean_dict(obj[i], func)
+    else:
+        pass
+    
 def get_access_token(creds):
     
     creds['client_id'] = os.environ['CODA_NOTEBOOK_APP_AUTH_CLIENT_ID']
@@ -23,6 +39,8 @@ def execute_query(service, action, sites, query, access_token):
 
     data = json.loads(data_response.text)
 
+    clean_dict(data, lambda x: x == "queries" or x == "query")
+    clean_dict(data, lambda x: x == "queries" or x == "query")
     return data
 
 def get_measure(data, measure):
